"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const SECTION_SEPARATOR = "_____";
class TextDocGenerator {
    generateDoc(config, packageConfig, outputter) {
        outputter.outputLine(SECTION_SEPARATOR);
        packageConfig.checkImportsBetweenPackages.packages
            .filter(pkg => !pkg.isThirdParty)
            .forEach(pkg => {
            const packageName = pkg.importPath;
            outputter.outputLine(`${packageName} - ${pkg.description}`);
            outputter.increaseIndent();
            this.outputAllowedImports(pkg, outputter);
            this.outputSubFolders(outputter, pkg.subFolders);
            outputter.decreaseIndent();
        });
        outputter.outputLine(SECTION_SEPARATOR);
    }
    outputAllowedImports(pkg, outputter) {
        const allowedToImport = this.outputAllowedToImport(pkg.allowedToImport);
        outputter.outputLine(`--> ${allowedToImport}`);
    }
    outputAllowedToImport(allowed) {
        if (allowed.some(value => value === "*")) {
            return "(any)";
        }
        return allowed.length > 0 ? `${allowed.join(", ")}` : "(none)";
    }
    outputSubFolders(outputter, subFolders) {
        if (subFolders.length === 0) {
            outputter.outputLine("");
            return;
        }
        outputter.increaseIndent();
        outputter.outputLine("folders:");
        outputter.increaseIndent();
        subFolders.forEach(folder => {
            outputter.outputLine(`${folder.importPath} - ${folder.description}`);
            const allowedToImport = this.outputAllowedToImport(folder.allowedToImport);
            outputter.increaseIndent();
            outputter.outputLine(`--> ${allowedToImport}`);
            outputter.decreaseIndent();
            outputter.outputLine("");
        });
        outputter.decreaseIndent();
        outputter.decreaseIndent();
    }
}
exports.TextDocGenerator = TextDocGenerator;
//# sourceMappingURL=TextDocGenerator.js.map