"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const ConfigFactory_1 = require("../../config/ConfigFactory");
const Config_1 = require("./Config");
const ErrorHandler_1 = require("./ErrorHandler");
const DocGeneratorFactory_1 = require("./generators/DocGeneratorFactory");
const ConsoleOutputter_1 = require("./outputters/ConsoleOutputter");
const handleError = (message, errorLevel = ErrorHandler_1.ErrorLevel.Fatal) => {
    console.error(message);
    if (errorLevel === ErrorHandler_1.ErrorLevel.Fatal) {
        process.exit(1);
    }
};
function getFormats() {
    let texts = [];
    for (let item in Config_1.DocFormat) {
        if (isNaN(Number(item))) {
            texts.push(item);
        }
    }
    return texts.join(", ");
}
function main() {
    console.log("package structure:");
    if (process.argv.length !== 4) {
        handleError(`USAGE: index.ts <path to tslint.json> <format>\n  where format is one of: ${getFormats()}`);
    }
    const formatString = process.argv[3];
    const format = Config_1.DocFormat[formatString];
    const config = {
        pathToTslintJson: process.argv[2],
        format: format
    };
    const generator = DocGeneratorFactory_1.DocGeneratorFactory.create(format);
    const outputter = new ConsoleOutputter_1.ConsoleOutputter();
    loadTslintConfig(config).then(packageConfig => {
        generator.generateDoc(config, packageConfig, outputter);
    });
}
function loadTslintConfig(config) {
    return new Promise((resolve, reject) => {
        fs.readFile(config.pathToTslintJson, "utf8", function (err, data) {
            if (err) {
                reject(err);
            }
            else {
                const json = JSON.parse(data);
                const packageConfigJson = json.rules["tslint-folders-imports-between-packages"][1];
                const packageConfig = ConfigFactory_1.ConfigFactory.create([packageConfigJson]);
                resolve(packageConfig);
            }
        });
    });
}
main();
//# sourceMappingURL=index.js.map