"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Lint = require("tslint");
const GeneralRuleUtils_1 = require("./utils/GeneralRuleUtils");
const RULE_ID = "tslint-folders-disabled-test";
class Rule extends Lint.Rules.AbstractRule {
    apply(sourceFile) {
        if (!GeneralRuleUtils_1.GeneralRuleUtils.isInTestFile(sourceFile.fileName)) {
            return [];
        }
        const walker = new StatementsWalker(sourceFile, this.getOptions());
        this.applyWithWalker(walker);
        return walker.getFailures();
    }
}
exports.Rule = Rule;
class StatementsWalker extends Lint.RuleWalker {
    visitCallExpression(node) {
        const text = node.getText();
        if (text.startsWith("describe.only") || text.startsWith("it.only")) {
            this.addFailureAtNode(node.getFirstToken(), GeneralRuleUtils_1.GeneralRuleUtils.buildFailureString("do not enable only some tests", RULE_ID));
        }
        if (text.startsWith("describe.skip") || text.startsWith("it.skip")) {
            this.addFailureAtNode(node.getFirstToken(), GeneralRuleUtils_1.GeneralRuleUtils.buildFailureString("do not disable tests", RULE_ID));
        }
        super.visitCallExpression(node);
    }
}
//# sourceMappingURL=tsLintFoldersDisabledTestRule.js.map