"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Lint = require("tslint");
class Rule extends Lint.Rules.AbstractRule {
    apply(sourceFile) {
        const walker = new ImportsWalker(sourceFile, this.getOptions());
        this.applyWithWalker(walker);
        return walker.getFailures();
    }
}
// include the rule ID, to make it easier to disable
Rule.FAILURE_STRING = "do not import from invalid folder like 'DISALLOWED_TEXT' (tslint-folders-import-from-disallowed-folders)";
exports.Rule = Rule;
class ImportsWalker extends Lint.RuleWalker {
    visitImportDeclaration(node) {
        this.validate(node, node.moduleSpecifier.getText());
    }
    visitImportEqualsDeclaration(node) {
        this.validate(node, node.moduleReference.getText());
        super.visitImportEqualsDeclaration(node);
    }
    validate(node, text) {
        const options = this.getOptions();
        if (options.length !== 1) {
            throw new Error("tslint rule is misconfigured (tslint-folders-import-from-disallowed-folders)");
        }
        const disallowedTexts = this.getOptions()[0].disallowed;
        for (const disallowed of disallowedTexts) {
            if (text.indexOf(disallowed) >= 0) {
                this.addFailureAtNode(node, Rule.FAILURE_STRING.replace("DISALLOWED_TEXT", disallowed));
                // one error per line is enough!
                return;
            }
        }
    }
}
//# sourceMappingURL=tsLintFoldersImportFromDisallowedFoldersRule.js.map