"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const GeneralRuleUtils_1 = require("./GeneralRuleUtils");
const PackageConfigHelper_1 = require("./PackageConfigHelper");
var PathSource;
(function (PathSource) {
    PathSource[PathSource["SourceFilePath"] = 0] = "SourceFilePath";
    PathSource[PathSource["ImportText"] = 1] = "ImportText";
})(PathSource = exports.PathSource || (exports.PathSource = {}));
var ImportRuleUtils;
(function (ImportRuleUtils) {
    ImportRuleUtils.IS_DEBUG_ENABLED = false;
    function determinePackageLocationFromPath(filePath, ruleId, config, pathSource) {
        const dirs = cleanPath(filePath).split("/");
        if (ImportRuleUtils.IS_DEBUG_ENABLED) {
            console.log(`checking ${PathSource[pathSource]} against path:`, dirs.join(","));
        }
        let packageName = null;
        switch (pathSource) {
            case PathSource.ImportText:
                {
                    // take the 1st part of the path:
                    // (ignore local directories that happen to have same name as a package)
                    packageName = dirs[0];
                }
                break;
            case PathSource.SourceFilePath: {
                dirs.forEach(dir => {
                    if (PackageConfigHelper_1.PackageConfigHelper.hasPackage(config, dir)) {
                        if (packageName === null) {
                            // take the 1st recognised folder:
                            packageName = dir;
                        }
                        else if (ImportRuleUtils.IS_DEBUG_ENABLED) {
                            // this can occur with package names like 'utils'
                            console.warn(`import has more than one recognised package: [${packageName},${dir}]`);
                        }
                    }
                });
                break;
            }
            default: {
                throw new Error(`unhandled PathSource ${pathSource}`);
            }
        }
        if (packageName === null ||
            !PackageConfigHelper_1.PackageConfigHelper.hasPackage(config, packageName)) {
            return {
                packageName: filePath
            };
        }
        let packageFolder;
        try {
            packageFolder = PackageConfigHelper_1.PackageConfigHelper.getPackage(config, packageName);
        }
        catch (error) {
            GeneralRuleUtils_1.GeneralRuleUtils.buildFailureString(`unexpected: import had a recognised package: [${packageName}] but could not find the PackageFolder in the config`, ruleId);
            return {
                packageName: filePath
            };
        }
        if (!packageFolder) {
            return {
                packageName: packageName
            };
        }
        // TODO xxx determine packageSubFolder
        return { packageName: packageName, packageFolder: packageFolder };
    }
    ImportRuleUtils.determinePackageLocationFromPath = determinePackageLocationFromPath;
    function cleanPath(filePath) {
        let cleaned = filePath.trim();
        cleaned = cleaned.replace(/['"]+/g, "");
        cleaned = cleaned.replace(/[\\]+/g, "\\");
        return cleaned;
    }
    function isThisPackageThirdParty(thisFolderLocation, node) {
        if (isPackageThirdParty(thisFolderLocation)) {
            if (ImportRuleUtils.IS_DEBUG_ENABLED) {
                console.log(node.getSourceFile().fileName, "- this package ThirdParty!", thisFolderLocation.packageName);
            }
            return true;
        }
        return false;
    }
    ImportRuleUtils.isThisPackageThirdParty = isThisPackageThirdParty;
    function isPackageThirdParty(folderLocation) {
        return !folderLocation.packageFolder && !folderLocation.packageSubFolder;
    }
    ImportRuleUtils.isPackageThirdParty = isPackageThirdParty;
    function logPackageAndImport(node, thisPackageLocation, importPackageLocation) {
        if (ImportRuleUtils.IS_DEBUG_ENABLED) {
            console.log(node.getSourceFile().fileName, "- this package:", thisPackageLocation.packageName, getPackageName(thisPackageLocation.packageFolder), "- import:", importPackageLocation.packageName, getPackageName(importPackageLocation.packageFolder));
        }
    }
    ImportRuleUtils.logPackageAndImport = logPackageAndImport;
    function getPackageName(packageFolder) {
        return packageFolder ? packageFolder.importPath : "(unknown)";
    }
    function shouldIgnoreFile(node, ignorePaths) {
        const filePath = node.getSourceFile().fileName;
        return ignorePaths.some(ignore => filePath.indexOf(ignore) >= 0);
    }
    ImportRuleUtils.shouldIgnoreFile = shouldIgnoreFile;
})(ImportRuleUtils = exports.ImportRuleUtils || (exports.ImportRuleUtils = {}));
//# sourceMappingURL=ImportRuleUtils.js.map